/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Community System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2001 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.venice.servlets.format;

import java.io.Writer;
import java.io.IOException;
import java.util.*;
import com.silverwrist.util.StringUtil;
import com.silverwrist.venice.core.*;

public class MenuSIG implements ComponentRender
{
  private String image_url;
  private boolean image_url_needs_fixup = false;
  private String title;
  private List items_list;
  private int sigid;
  private boolean show_unjoin;

  public MenuSIG(SIGContext ctxt)
  {
    try
    { // retrieve the contact info for this puppy
      ContactInfo ci = ctxt.getContactInfo();
      image_url = ci.getPhotoURL();
      if (StringUtil.isStringEmpty(image_url))
      { // just hit the default
	image_url = "default_sig_logo.gif";
	image_url_needs_fixup = true;

      } // end if

    } // end try
    catch (DataException e)
    { // if we couldn't get the contact info, screw it
      image_url = null;

    } // end catch

    title = ctxt.getName();
    items_list = ctxt.getSIGFeaturesList();
    sigid = ctxt.getSIGID();
    show_unjoin = ctxt.canUnjoin();

  } // end constructor

  public int getID()
  {
    return sigid;

  } // end getID

  public void renderHere(Writer out, RenderData rdat) throws IOException
  {
    if (image_url!=null)
    { // display the image by URL
      if (image_url_needs_fixup)
      { // fix up the URL...
	image_url = rdat.getFullImagePath(image_url);
	image_url_needs_fixup = false;

      } // end if

      out.write("<DIV ALIGN=\"LEFT\"><IMG SRC=\"" + image_url + "\" WIDTH=110 HEIGHT=65 BORDER=0></DIV>\n");

    } // end if

    // display the title
    out.write("<B>" + StringUtil.encodeHTML(title) + "</B>");

    // display the menu items
    Iterator it = items_list.iterator();
    while (it.hasNext())
    { // display each menu item in turn
      SIGFeature ftr = (SIGFeature)(it.next());
      out.write("<BR>\n<A HREF=\"" + rdat.getEncodedServletPath(ftr.getApplet() + "?sig="
								+ String.valueOf(sigid)));
      out.write("\">" + StringUtil.encodeHTML(ftr.getName()) + "</A>\n");

    } // end while

    if (show_unjoin)
      out.write("<P>\n<A HREF=\"" + rdat.getEncodedServletPath("sigops?cmd=U&sig=" + String.valueOf(sigid))
		+ "\">Unjoin</A>\n");

    out.write("\n");  // all done...

  } // end renderHere
  
} // end class MenuTop
