/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2001 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.venice.servlets.format;

import java.io.*;
import java.util.*;
import com.silverwrist.util.StringUtil;
import com.silverwrist.venice.core.*;

public class SideBoxSIGs implements ContentRender
{
  /*--------------------------------------------------------------------------------
   * Attributes
   *--------------------------------------------------------------------------------
   */

  private UserContext uc;
  private List sig_list;

  /*--------------------------------------------------------------------------------
   * Constructor
   *--------------------------------------------------------------------------------
   */

  public SideBoxSIGs(UserContext uc, String parameter) throws DataException
  {
    this.uc = uc;
    this.sig_list = uc.getMemberSIGs();

  } // end constructor

  /*--------------------------------------------------------------------------------
   * Implementations from interface VeniceContent
   *--------------------------------------------------------------------------------
   */

  public String getPageTitle(RenderData rdat)
  {
    if (uc.isLoggedIn())
      return "Your SIGs:";
    else
      return "Featured SIGs:";

  } // end getPageTitle

  /*--------------------------------------------------------------------------------
   * Implementations from interface ContentRender
   *--------------------------------------------------------------------------------
   */

  public void renderHere(Writer out, RenderData rdat) throws IOException
  {
    out.write(rdat.getStdFontTag(null,2) + "\n");
    if (sig_list.size()>0)
    { // display the list of available SIGs
      out.write("<TABLE ALIGN=CENTER BORDER=0 CELLPADDING=0 CELLSPACING=2>\n");
      Iterator it = sig_list.iterator();
      while (it.hasNext())
      { // display the names of the SIGs one by one
	SIGContext sig = (SIGContext)(it.next());
	out.write("<TR VALIGN=MIDDLE>\n<TD ALIGN=CENTER WIDTH=14><IMG SRC=\""
		  + rdat.getFullImagePath("purple-ball.gif")
		  + "\" ALT=\"*\" WIDTH=14 HEIGHT=14 BORDER=0></TD>\n");
	out.write("<TD ALIGN=LEFT>\n" + rdat.getStdFontTag(null,2) + "<B><A HREF=\""
		  + rdat.getEncodedServletPath("sig/" + sig.getAlias()) + "\">"
		  + StringUtil.encodeHTML(sig.getName()) + "</A></B></FONT>\n");
	if (sig.isAdmin())
	  out.write("&nbsp;<IMG SRC=\"" + rdat.getFullImagePath("tag_host.gif")
		    + "\" ALT=\"Host!\" BORDER=0 WIDTH=40 HEIGHT=20>\n");
	out.write("</TD>\n</TR>\n");

      } // end while

      out.write("</TABLE>\n");

    } // end if
    else
      out.write(rdat.getStdFontTag(null,2) + "<EM>You are not a member of any SIGs.</EM></FONT>\n");

    if (uc.isLoggedIn())
    { // write the two links at the end
      out.write("<P>" + rdat.getStdFontTag(null,1) + "<B>[ <A HREF=\""
		+ rdat.getEncodedServletPath("settings?cmd=S") + "\">Manage</A> | <A HREF=\""
                + rdat.getEncodedServletPath("sigops?cmd=C") + "\">Create New</A> ]</B></FONT>");
    } // end if

  } // end renderHere

} // end class SideBoxSIGs

